<?php

namespace Drupal\reader\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the channels block.
 *
 * @Block(
 *   id = "reader_channels",
 *   admin_label = @Translation("Reader channels"),
 *   category = @Translation("Reader")
 * )
 */
class Channels extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Channels constructor
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ModuleHandlerInterface $module_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $channels = [];

    foreach ($this->moduleHandler->getImplementations('reader_channels') as $module) {
      $function = $module . '_reader_channels';
      if (function_exists($function)) {
        $data = $function();
        if (!empty($data['channels'])) {
          $items = [];
          foreach ($data['channels'] as $channel) {
            $unread = !empty($channel->unread) ? ' (' .  $channel->unread .')' : '';
            $items[] = Link::fromTextAndUrl($channel->name . $unread, Url::fromRoute('reader.timeline', ['module' => strtr($module, '_', '-'), 'id' => $channel->uid], ['attributes' => ['class' => ['column-link']]]));
          }
          $channels[] = [
            'label' => $data['label'],
            'items' => $items,
          ];
        }
      }
    }

    return [
      '#theme' => 'reader_channels_list',
      '#channels' => $channels,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
