<?php

namespace Drupal\reader;

interface ReaderInterface {

  const SEPARATOR = '::';

  /**
   * Returns a list of channels.
   *
   * @See https://indieweb.org/Microsub-spec#Channels_2 to format the 'channels'
   * key of this return.
   *
   * [
   *   'label' => 'My label',
   *   'channels' => [],
   * ]
   *
   * @return array
   */
  public function getChannels();

  /**
   * Get the timeline.
   *
   * @param $id
   *   The channel id to view.
   * @param $search
   *   The search terms.
   *
   * @see https://indieweb.org/Microsub-spec#Retrieve_Entries_in_a_Channel to
   * format the response.
   *
   * @return array
   */
  public function getTimeline($id, $search = NULL);

  /**
   * Returns a list of timeline action links.
   *
   * @param $id
   *   The channel id to get the actions for.
   *
   * @return array
   */
  public function getTimelineActions($id);

  /**
   * Do a timeline action.
   *
   * @param $action
   * @param $id
   *
   * @return mixed
   */
  public function doTimelineAction($action, $id);

}
