(function ($, drupalSettings) {

  'use strict';

  let searchVisible = false;
  let searchWrapper = null;

  Drupal.behaviors.reader = {
    attach: function () {

      // When clicking on the home button, we'll compare the current path. In
      // case it's the same we simply switch the classes instead of loading the
      // page.
      let path = drupalSettings.path.baseUrl + drupalSettings.path.currentPath;

      // Get columns.
      let column1 = $('.column-1');
      let column2 = $('.column-2');
      let column3 = $('.column-3');

      // Get search elements.
      let search = $('.column-header__button.search');
      searchWrapper = $('.column-header__collapsible.search-container');

      // Get button links to set active classes and hide/show columns.
      $('.button-link').on('click', function(e) {
        let type = $(this).data('button');

        // Do not reload page on home.
        if (type === 'home' && path === '/reader') {
          e.preventDefault();
        }

        // Active class.
        $('.tabs-bar a').removeClass('active');
        $(this).addClass('active');

        switch (type) {
          case 'home':
            column2.css('display', 'none');
            column3.css('display', 'none');
            column1.css('display', 'flex');
            hideSearch();
            break;
          case 'read':
            column1.css('display', 'none');
            column3.css('display', 'none');
            column2.css('display', 'flex');
            hideSearch();
            break;
          case 'write':
            column1.css('display', 'none');
            column2.css('display', 'none');
            column3.css('display', 'flex');
            hideSearch();
            break;
          case 'search':
            column1.css('display', 'flex');
            column2.css('display', 'none');
            column3.css('display', 'none');
            if (!searchVisible) {
              searchVisible = true;
              searchWrapper.removeClass('collapsed');
            }
        }
      });

      // Action links.
      $('.status__action-bar-dropdown').on('click', function () {
        $(this).parent().children('.status__action-bar-links').show();
      });

      // Hide messages.
      let messages = $('.drupal-messages');
      if (messages.length > 0) {
        setTimeout(function() { messages.hide('slow') }, 3000);
      }

      // Catch clicks on links inside the article, apart from gallery and action
      // links, to open in a new tab or window (depending on browser).
      $('.content-article a:not(.image-gallery-item,.status__action-bar-links a)').on('click', function(e) {
        e.preventDefault();
        let url = $(this).attr('href');
        window.open(url, '_blank');
      });

      // Show or hide actions.
      let actionsVisible = false;
      let actions = $('.column-header__button.actions');
      let actionsWrapper = $('.column-header__collapsible.actions-container');
      if (actions.length > 0 && actionsWrapper.length > 0) {
        actions.on('click', function() {
          if (actionsVisible) {
            actionsVisible = false;
            actionsWrapper.addClass('collapsed');
          }
          else {
            actionsWrapper.removeClass('collapsed');
            actionsVisible = true;
          }
        });
      }

      if (search.length > 0 && searchWrapper.length > 0) {
        search.on('click', function() {
          if (searchVisible) {
            searchVisible = false;
            searchWrapper.addClass('collapsed');
          }
          else {
            searchWrapper.removeClass('collapsed');
            searchVisible = true;
          }
        });
      }

      // Read more.
      if (drupalSettings.reader.readMore) {
        readMore(drupalSettings.reader.readMoreHeight);
      }

    }
  };

  /**
   * Apply read more to posts.
   *
   * @param height
   */
  function readMore(height) {

    let closeHeight = height;
    let moreText 	= Drupal.t('Read more');
    let lessText	= Drupal.t('Close');
    let duration	= '1000';
    let easing = 'linear';

    $('.main-content').each(function() {
      if ($(this).height() > height) {
        $(this).data('fullHeight', $(this).height()).css('height', height);
        $(this).after('<a href="javascript:void(0);" class="reader-more-link closed">' + moreText + '</a>');
      }
    });

    let openSlider = function() {
      let link = $(this);
      let openHeight = link.prev('.main-content').data('fullHeight') + 'px';
      link.prev('.main-content').animate({'height': openHeight}, {duration: duration }, easing);
      link.text(lessText).addClass('open').removeClass('closed');
      link.unbind('click', openSlider);
      link.bind('click', closeSlider);
    }

    let closeSlider = function() {
      let link = $(this);
      link.prev('.main-content').animate({'height': closeHeight}, {duration: duration }, easing);
      link.text(moreText).addClass('closed').removeClass('open');
      link.unbind('click');
      link.bind('click', openSlider);
    }

    $('.reader-more-link').bind('click', openSlider);
  }

  /**
   * Hide search.
   */
  function hideSearch() {
    if (searchVisible && searchWrapper.length > 0) {
      searchVisible = false;
      searchWrapper.addClass('collapsed');
    }
  }

})(jQuery, drupalSettings);
